"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const disposable_1 = require("@phosphor/disposable");
const apputils_1 = require("@jupyterlab/apputils");
/**
 * The plugin registration information.
 */
const plugin = {
    activate,
    id: 'jupyter-lti:buttonPlugin',
    autoStart: true
};
/**
 * A notebook widget extension that adds a button to the toolbar.
 */
class ButtonExtension {
    constructor(assignment_id) {
        this.assignment_id = assignment_id;
    }
    /**
     * Create a new extension object.
     */
    createNew(panel, context) {
        let self = this;
        let callback = () => {
            let url = window.location.pathname.split('endpoint')[0] +
                'lti/assignment/' +
                self.assignment_id +
                '/';
            let buttons = [apputils_1.Dialog.okButton()];
            let errorDialog = {
                title: 'Error',
                body: 'There was an error while sending submission',
                buttons: buttons
            };
            context.save();
            fetch(url, {
                method: 'POST',
                body: JSON.stringify({ path: context.path }),
                headers: { 'Content-Type': 'application/json;charset=utf-8' },
                referrerPolicy: 'no-referrer'
            })
                .then(res => {
                if (!res.ok) {
                    console.log(res);
                    apputils_1.showDialog(errorDialog);
                }
                else {
                    apputils_1.showDialog({
                        title: 'Success',
                        body: 'Your assignment was sent to Canvas',
                        buttons: buttons
                    });
                }
            })
                .catch(error => {
                apputils_1.showDialog(errorDialog);
                console.error(error);
            });
        };
        let button = new apputils_1.ToolbarButton({
            className: 'myButton',
            iconClassName: 'fa fa-share-square',
            onClick: callback,
            tooltip: 'Submit to Canvas'
        });
        panel.toolbar.insertItem(0, 'submit', button);
        return new disposable_1.DisposableDelegate(() => {
            button.dispose();
        });
    }
}
exports.ButtonExtension = ButtonExtension;
/**
 * Activate the extension.
 */
function activate(app) {
    let query = new URLSearchParams(window.location.search);
    let assignment_id = query.get('assignment_id');
    if (!!assignment_id) {
        app.docRegistry.addWidgetExtension('Notebook', new ButtonExtension(query.get('assignment_id')));
    }
}
/**
 * Export the plugin as default.
 */
exports.default = plugin;
